@@ -1,21 +1,14 @@
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# 2009-06-09
-# o Grammar fix: is(Homo|Hetero)zygous(), not is(Homo|Hetero)zygote().
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-setMethodS3("isHomozygote", "AromaUnitGenotypeCallFile", function(...) {
-  .Defunct("isHomozygous");
-  isHomozygous(...);
-}, private=TRUE, deprecated=TRUE)
+setMethodS3("downloadPackagePatch", "default", function(pkgName, version=NULL, url=NULL, apply=TRUE, rootPath="~/.Rpatches", pkgVer=NULL, ..., verbose=FALSE) {
+  .Defunct(msg="downloadPackagePatch() is deprecated without alternatives.");
+}, protected=TRUE, deprecated=TRUE)
 
-setMethodS3("isHeterozygote", "AromaUnitGenotypeCallFile", function(...) {
-  .Defunct("isHeterozygous");
-  isHeterozygous(...);
-}, private=TRUE, deprecated=TRUE)
+setMethodS3("patchPackage", "default", function(pkgName, paths=c("~/.Rpatches/", "patches/"), deleteOld=TRUE, verbose=FALSE, ...) {
+  .Defunct(msg="patchPackage() is deprecated without alternatives.");
+}, protected=TRUE, deprecated=TRUE)
 
 
-setMethodS3("getPhysicalPositions", "RawCopyNumbers", function(this, ...) {
-  .Defunct("getPositions");
-  getPositions(this, ...);
+setMethodS3("patch", "AromaPackage", function(this, ..., verbose=FALSE) {
+  .Defunct(msg="patch() for AromaPackage is deprecated without alternatives.");
 }, protected=TRUE, deprecated=TRUE)
 
 
@@ -27,13 +20,12 @@ setMethodS3("readData", "SampleAnnotationFile", function(this, ...) {
 }, protected=TRUE, deprecated=TRUE)
 
 
-
 # 2009-12-30
 # o Dropped nbrOfArrays(); use nbrOfFiles() instead.
 setMethodS3("nbrOfArrays", "AromaMicroarrayDataSetTuple", function(this, ...) {
   .Deprecated("length");
   length(this, ...);
-}, protected=TRUE)
+}, protected=TRUE, deprecated=TRUE)
 
 
 # 2013-01-03
@@ -42,19 +34,25 @@ setMethodS3("nbrOfArrays", "AromaMicroarrayDataSetTuple", function(this, ...) {
 setMethodS3("nbrOfArrays", "AromaMicroarrayDataSet", function(this, ...) {
   .Deprecated("length");
   length(this, ...);
-})
+}, protected=TRUE, deprecated=TRUE)
 
 setMethodS3("nbrOfArrays", "AromaUnitTotalCnBinarySet", function(this, ...) {
   .Deprecated("length");
   length(this, ...);
-}, protected=TRUE)
+}, protected=TRUE, deprecated=TRUE)
 
 
 
 ############################################################################
 # HISTORY:
+# 2014-02-28
+# o CLEANUP: Defuncted previously deprecated downloadPackagePatch() and
+#   patchPackage() as well as patch() for AromaPackage.
+# 2014-02-28
+# o CLEANUP: Removed defunct methods, i.e. is(Homo|Hetero)zygote() and
+#   getPhysicalPositions().
 # 2013-04-20
-# o CLEANUP: Made is(Homo|Hetero)zygote() defunct.
+# o CLEANUP: Made is(Homo|Hetero)zygote() & getPhysicalPositions() defunct.
 # 2012-10-14
 # o Created 999.DEPRECATED.R.
 # 2011-02-18
