@@ -8,7 +8,7 @@
 #   @get "title" with or without file header comments.
 # }
 #
-# @usage
+# @synopsis
 #
 # \arguments{
 #  \item{filename}{The filename of generated file.}
@@ -28,7 +28,7 @@
 #  \item{sep}{A @character string specifying the column separator}.
 #  \item{columnNamesPrefix}{A @character string specifying what type
 #    of prefix should be used for column names.}
-#  \item{overwrite}{If @TRUE, an existing destination file will be 
+#  \item{overwrite}{If @TRUE, an existing destination file will be
 #    overwritten, otherwise an exception will be thrown.}
 #   \item{verbose}{A @logical or a @see "R.utils::Verbose" object.}
 # }
@@ -42,11 +42,11 @@
 # \seealso{
 #  @seeclass
 # }
-#*/########################################################################### 
+#*/###########################################################################
 setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filename=sprintf("%s.txt", getFilename(this)), path=file.path(getRootName(this, tags="*,txt"), getFullName(this), getChipType(this, fullname=FALSE)), ..., columns=c("unitName", "*"), sep="\t", addHeader=TRUE, createdBy=NULL, nbrOfDecimals=4L, columnNamesPrefix=c("fullname", "name", "none"), overwrite=FALSE, verbose=FALSE) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Local functions
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   getAnnotationData <- function(df, columns, ...) {
     res <- list();
 
@@ -57,14 +57,15 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
       verbose && enter(verbose, "Unit names");
       unf <- getUnitNamesFile(this);
       verbose && cat(verbose, "Filename: ", getFilename(unf));
-  
+
       unitNames <- getUnitNames(unf);
       verbose && str(verbose, unitNames);
       # Sanity check
       stopifnot(length(unitNames) == nbrOfUnits(df));
 
       res$unitName <- unitNames;
-      rm(unitNames);
+      # Not needed anymore
+      unitNames <- NULL;
 
       verbose && exit(verbose);
     }
@@ -76,7 +77,7 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
     verbose && str(verbose, res);
 
     verbose && exit(verbose);
-  
+
     res;
   } # getAnnotationData()
 
@@ -119,7 +120,7 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
   overwrite <- Arguments$getLogical(overwrite);
 
   # Argument 'filename' & 'path':
-  pathname <- Arguments$getWritablePathname(filename, path=path, 
+  pathname <- Arguments$getWritablePathname(filename, path=path,
                                                   mustNotExist=!overwrite);
 
   # Argument 'addHeader':
@@ -165,7 +166,7 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
   # Add annotation data columns?
   adColumnNames <- intersect(knownAnnotationColumnNames, columns);
   if (length(adColumnNames) > 0) {
-    adData <- getAnnotationData(this, columns=adColumnNames, 
+    adData <- getAnnotationData(this, columns=adColumnNames,
                                                  verbose=less(verbose, 5));
   } else {
     adData <- NULL;
@@ -176,7 +177,7 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
   # Generate file header
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   nbrOfColumns <- nbrOfColumns(this);
- 
+
   hdr <- NULL;
   if (addHeader) {
     verbose && enter(verbose, "Generating file header");
@@ -212,14 +213,15 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
       columnNames <- paste(prefixes, columnNames, sep=",");
     }
     # Sanity check
-    columnNames <- Arguments$getCharacters(columnNames, 
+    columnNames <- Arguments$getCharacters(columnNames,
                                       length=rep(nbrOfColumns, 2));
 
     adColumnNames <- colnames(adData);
     allColumnNames <- c(adColumnNames, columnNames);
     allColumnNamesStr <- paste(allColumnNames, collapse="\t");
     hdr <- c(hdr, sprintf("columnNames: %s", allColumnNamesStr));
-    rm(allColumnNamesStr);
+    # Not needed anymore
+    allColumnNamesStr <- NULL;
 
     # Turn into file comments
     hdr <- paste("# ", hdr, sep="");
@@ -227,7 +229,7 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
 
     verbose && exit(verbose);
   } # if (addHeader)
-  
+
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Generate data table
@@ -261,7 +263,8 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
     }
 
     data[,cc] <- values;
-    rm(values);
+    # Not needed anymore
+    values <- NULL;
   } # for (cc ...)
 
   verbose && cat(verbose, "Data without annotation data:");
@@ -277,7 +280,8 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
     verbose && str(verbose, data);
     verbose && exit(verbose);
   }
-  rm(adData);
+  # Not needed anymore
+  adData <- NULL;
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -311,9 +315,10 @@ setMethodS3("writeDataFrame", "AromaUnitTabularBinaryFile", function(this, filen
   allColumnNamesStr <- paste(allColumnNames, collapse=sep);
   cat(file=pathnameT, allColumnNamesStr, sep="\n", append=TRUE);
 
-  write.table(file=pathnameT, data, sep=sep, quote=FALSE, row.names=FALSE, 
+  write.table(file=pathnameT, data, sep=sep, quote=FALSE, row.names=FALSE,
                                             col.names=FALSE, append=TRUE);
-  rm(data);
+  # Not needed anymore
+  data <- NULL;
   verbose && exit(verbose);
 
   # Renaming temporary file
